
function Create()

    -- property doesn't exist on the object by default, so it must be created now
    Object.SetProperty( "Age", 0);  
    
    local ourX = Object.GetProperty("Pos.x");
    local ourY = Object.GetProperty("Pos.y");
    
    -- pick randomly between iron, copper or clay
    oreType = "Coal";
    
    if ourX > ourY then
        outcome = ourY / ourX;
    else
        outcome = ourX / ourY;
    end
    
    if (ourX % ourY) == 0 then
        oreType = "None";
    elseif outcome > 0.75 then
        oreType = "RawIron";
    elseif outcome > 0.50 then
        oreType = "RawCopper";
    elseif outcome > 0.25 then
        oreType = "RawClay";
    else
    	oreType = "Coal";
    end
    Object.SetProperty("OreType", oreType );
    
    Object.SetProperty("CanBeMined", false);
    Object.CreateJob("Prospecting");
    Object.SetProperty("Prospected", false);
end


function Update( timePassed )

    -- get the material that the object is currently placed in
    local ourX = Object.GetProperty("Pos.x");
    local ourY = Object.GetProperty("Pos.y");
    local material = Object.GetMaterial( ourX, ourY );
    local oreType = Object.GetProperty("OreType")
    
    -- A quarry will only opperate on soft materials!
    if material ~= "Dirt" and material ~= "Grass" and material ~= "Sand" then
        Object.SetProperty("Tooltip", "tooltip_quarry_unminableground");
        return;
    end   -- end of if   
    
    local maxAge = 600.0;
    
    if Object.GetProperty("CanBeMined") and Object.GetProperty("OreType") ~= "None" then
        Object.CreateJob("MiningAndDigging");
        Object.SetProperty("Tooltip", "tooltip_quarry_canbemined");
        Object.SetProperty("CanBeMined", false);
        return;
    end   -- end of if  
    
    -- clear the tooltip
    Object.SetProperty("Tooltip", oreType);  
        
    -- increase our age and save it back to the object
    local age = Object.GetProperty("Age");  
    age = age + timePassed;    
    Object.SetProperty( "Age", age );
    
    -- set our subtype (and thus, our sprite) based on our age
    
    if Object.GetProperty("Prospected") then       
       local subType = 1;
		 if age < maxAge * 0.15 then
		     subType = 1;
		 elseif age < maxAge * 0.35 and oreType == "RawCopper" then
		     subType = 5;  
		 elseif age < maxAge * 0.35 and oreType == "RawIron" then
		     subType = 3; 
		 elseif age < maxAge * 0.5 and oreType == "RawCopper" then
		     subType = 4;   
		 elseif age < maxAge * 0.5 and oreType == "RawIron" then
		     subType = 2; 
		 elseif oreType == "Coal" then
		     subType = 7; 
		 else
		     subType = 6;
		 end
		 
		 local currentSubtype = Object.GetProperty("SubType");
       if currentSubtype ~= subType then
           Object.SetProperty("SubType", subType);    
       end
    end -- end object.getproperty  

	 if age > maxAge then        
		 Object.SetProperty( "Age", 0 );
		 Object.SetProperty( "SubType", 1 );    
	 end

	-- this function is called when the job created by the Object.CreateJob("TendVegetables") call is completed by the appropriate worker
	-- the name of the function called follows the format "JobComplete_" plus the name of the job (as created in jobs.txt, and called in the CreateJob function)
	function JobComplete_MiningAndDigging()
		 local ourX = Object.GetProperty("Pos.x");
		 local ourY = Object.GetProperty("Pos.y");
		 
		 -- spawn a ore at our position
		 local name = Object.Spawn( Object.GetProperty("OreType"), ourX, ourY );
		 
		 if name ~= nil then
		     local velX = -1.0 + math.random() + math.random();
		     local velY = -1.0 + math.random() + math.random();         
		     -- make the vegetable move slightly away from the plant, then reset our age
		     Object.ApplyVelocity(name, velX, velY);
		 end
		     
		 Object.SetProperty("CanBeMined", true); 
    end --jobcomplete   
end

function JobComplete_Prospecting()
    Object.SetProperty("Prospected", true);
    Object.SetProperty("CanBeMined", true);
    
    Object.SetProperty( "Age", 0 );
    Object.SetProperty( "SubType", 1 );
end
